# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HomerRecord(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HomerRecord - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date': 'datetime',
            'milli_ts': 'str',
            'micro_ts': 'str',
            'method': 'str',
            'reply_reason': 'str',
            'ruri': 'str',
            'ruri_user': 'str',
            'ruri_domain': 'str',
            'from_user': 'str',
            'from_domain': 'str',
            'from_tag': 'str',
            'to_user': 'str',
            'to_domain': 'str',
            'to_tag': 'str',
            'pid_user': 'str',
            'contact_user': 'str',
            'auth_user': 'str',
            'callid': 'str',
            'callid_aleg': 'str',
            'via1': 'str',
            'via1_branch': 'str',
            'cseq': 'str',
            'diversion': 'str',
            'reason': 'str',
            'content_type': 'str',
            'auth': 'str',
            'user_agent': 'str',
            'source_ip': 'str',
            'source_port': 'str',
            'destination_ip': 'str',
            'destination_port': 'str',
            'contact_ip': 'str',
            'contact_port': 'str',
            'originator_ip': 'str',
            'originator_port': 'str',
            'correlation_id': 'str',
            'proto': 'str',
            'family': 'str',
            'rtp_stat': 'str',
            'type': 'str',
            'node': 'str',
            'trans': 'str',
            'dbnode': 'str',
            'msg': 'str',
            'source_alias': 'str',
            'destination_alias': 'str',
            'conversation_id': 'str',
            'participant_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date': 'date',
            'milli_ts': 'milliTs',
            'micro_ts': 'microTs',
            'method': 'method',
            'reply_reason': 'replyReason',
            'ruri': 'ruri',
            'ruri_user': 'ruriUser',
            'ruri_domain': 'ruriDomain',
            'from_user': 'fromUser',
            'from_domain': 'fromDomain',
            'from_tag': 'fromTag',
            'to_user': 'toUser',
            'to_domain': 'toDomain',
            'to_tag': 'toTag',
            'pid_user': 'pidUser',
            'contact_user': 'contactUser',
            'auth_user': 'authUser',
            'callid': 'callid',
            'callid_aleg': 'callidAleg',
            'via1': 'via1',
            'via1_branch': 'via1Branch',
            'cseq': 'cseq',
            'diversion': 'diversion',
            'reason': 'reason',
            'content_type': 'contentType',
            'auth': 'auth',
            'user_agent': 'userAgent',
            'source_ip': 'sourceIp',
            'source_port': 'sourcePort',
            'destination_ip': 'destinationIp',
            'destination_port': 'destinationPort',
            'contact_ip': 'contactIp',
            'contact_port': 'contactPort',
            'originator_ip': 'originatorIp',
            'originator_port': 'originatorPort',
            'correlation_id': 'correlationId',
            'proto': 'proto',
            'family': 'family',
            'rtp_stat': 'rtpStat',
            'type': 'type',
            'node': 'node',
            'trans': 'trans',
            'dbnode': 'dbnode',
            'msg': 'msg',
            'source_alias': 'sourceAlias',
            'destination_alias': 'destinationAlias',
            'conversation_id': 'conversationId',
            'participant_id': 'participantId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date = None
        self._milli_ts = None
        self._micro_ts = None
        self._method = None
        self._reply_reason = None
        self._ruri = None
        self._ruri_user = None
        self._ruri_domain = None
        self._from_user = None
        self._from_domain = None
        self._from_tag = None
        self._to_user = None
        self._to_domain = None
        self._to_tag = None
        self._pid_user = None
        self._contact_user = None
        self._auth_user = None
        self._callid = None
        self._callid_aleg = None
        self._via1 = None
        self._via1_branch = None
        self._cseq = None
        self._diversion = None
        self._reason = None
        self._content_type = None
        self._auth = None
        self._user_agent = None
        self._source_ip = None
        self._source_port = None
        self._destination_ip = None
        self._destination_port = None
        self._contact_ip = None
        self._contact_port = None
        self._originator_ip = None
        self._originator_port = None
        self._correlation_id = None
        self._proto = None
        self._family = None
        self._rtp_stat = None
        self._type = None
        self._node = None
        self._trans = None
        self._dbnode = None
        self._msg = None
        self._source_alias = None
        self._destination_alias = None
        self._conversation_id = None
        self._participant_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this HomerRecord.
        The globally unique identifier for the object.

        :return: The id of this HomerRecord.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HomerRecord.
        The globally unique identifier for the object.

        :param id: The id of this HomerRecord.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this HomerRecord.


        :return: The name of this HomerRecord.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HomerRecord.


        :param name: The name of this HomerRecord.
        :type: str
        """
        
        self._name = name

    @property
    def date(self):
        """
        Gets the date of this HomerRecord.
        metadata associated to the SIP calls. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date of this HomerRecord.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this HomerRecord.
        metadata associated to the SIP calls. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date: The date of this HomerRecord.
        :type: datetime
        """
        
        self._date = date

    @property
    def milli_ts(self):
        """
        Gets the milli_ts of this HomerRecord.
        metadata associated to the SIP calls

        :return: The milli_ts of this HomerRecord.
        :rtype: str
        """
        return self._milli_ts

    @milli_ts.setter
    def milli_ts(self, milli_ts):
        """
        Sets the milli_ts of this HomerRecord.
        metadata associated to the SIP calls

        :param milli_ts: The milli_ts of this HomerRecord.
        :type: str
        """
        
        self._milli_ts = milli_ts

    @property
    def micro_ts(self):
        """
        Gets the micro_ts of this HomerRecord.
        metadata associated to the SIP calls

        :return: The micro_ts of this HomerRecord.
        :rtype: str
        """
        return self._micro_ts

    @micro_ts.setter
    def micro_ts(self, micro_ts):
        """
        Sets the micro_ts of this HomerRecord.
        metadata associated to the SIP calls

        :param micro_ts: The micro_ts of this HomerRecord.
        :type: str
        """
        
        self._micro_ts = micro_ts

    @property
    def method(self):
        """
        Gets the method of this HomerRecord.
        metadata associated to the SIP calls

        :return: The method of this HomerRecord.
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """
        Sets the method of this HomerRecord.
        metadata associated to the SIP calls

        :param method: The method of this HomerRecord.
        :type: str
        """
        
        self._method = method

    @property
    def reply_reason(self):
        """
        Gets the reply_reason of this HomerRecord.
        metadata associated to the SIP calls

        :return: The reply_reason of this HomerRecord.
        :rtype: str
        """
        return self._reply_reason

    @reply_reason.setter
    def reply_reason(self, reply_reason):
        """
        Sets the reply_reason of this HomerRecord.
        metadata associated to the SIP calls

        :param reply_reason: The reply_reason of this HomerRecord.
        :type: str
        """
        
        self._reply_reason = reply_reason

    @property
    def ruri(self):
        """
        Gets the ruri of this HomerRecord.
        metadata associated to the SIP calls

        :return: The ruri of this HomerRecord.
        :rtype: str
        """
        return self._ruri

    @ruri.setter
    def ruri(self, ruri):
        """
        Sets the ruri of this HomerRecord.
        metadata associated to the SIP calls

        :param ruri: The ruri of this HomerRecord.
        :type: str
        """
        
        self._ruri = ruri

    @property
    def ruri_user(self):
        """
        Gets the ruri_user of this HomerRecord.
        metadata associated to the SIP calls

        :return: The ruri_user of this HomerRecord.
        :rtype: str
        """
        return self._ruri_user

    @ruri_user.setter
    def ruri_user(self, ruri_user):
        """
        Sets the ruri_user of this HomerRecord.
        metadata associated to the SIP calls

        :param ruri_user: The ruri_user of this HomerRecord.
        :type: str
        """
        
        self._ruri_user = ruri_user

    @property
    def ruri_domain(self):
        """
        Gets the ruri_domain of this HomerRecord.
        metadata associated to the SIP calls

        :return: The ruri_domain of this HomerRecord.
        :rtype: str
        """
        return self._ruri_domain

    @ruri_domain.setter
    def ruri_domain(self, ruri_domain):
        """
        Sets the ruri_domain of this HomerRecord.
        metadata associated to the SIP calls

        :param ruri_domain: The ruri_domain of this HomerRecord.
        :type: str
        """
        
        self._ruri_domain = ruri_domain

    @property
    def from_user(self):
        """
        Gets the from_user of this HomerRecord.
        metadata associated to the SIP calls

        :return: The from_user of this HomerRecord.
        :rtype: str
        """
        return self._from_user

    @from_user.setter
    def from_user(self, from_user):
        """
        Sets the from_user of this HomerRecord.
        metadata associated to the SIP calls

        :param from_user: The from_user of this HomerRecord.
        :type: str
        """
        
        self._from_user = from_user

    @property
    def from_domain(self):
        """
        Gets the from_domain of this HomerRecord.
        metadata associated to the SIP calls

        :return: The from_domain of this HomerRecord.
        :rtype: str
        """
        return self._from_domain

    @from_domain.setter
    def from_domain(self, from_domain):
        """
        Sets the from_domain of this HomerRecord.
        metadata associated to the SIP calls

        :param from_domain: The from_domain of this HomerRecord.
        :type: str
        """
        
        self._from_domain = from_domain

    @property
    def from_tag(self):
        """
        Gets the from_tag of this HomerRecord.
        metadata associated to the SIP calls

        :return: The from_tag of this HomerRecord.
        :rtype: str
        """
        return self._from_tag

    @from_tag.setter
    def from_tag(self, from_tag):
        """
        Sets the from_tag of this HomerRecord.
        metadata associated to the SIP calls

        :param from_tag: The from_tag of this HomerRecord.
        :type: str
        """
        
        self._from_tag = from_tag

    @property
    def to_user(self):
        """
        Gets the to_user of this HomerRecord.
        metadata associated to the SIP calls

        :return: The to_user of this HomerRecord.
        :rtype: str
        """
        return self._to_user

    @to_user.setter
    def to_user(self, to_user):
        """
        Sets the to_user of this HomerRecord.
        metadata associated to the SIP calls

        :param to_user: The to_user of this HomerRecord.
        :type: str
        """
        
        self._to_user = to_user

    @property
    def to_domain(self):
        """
        Gets the to_domain of this HomerRecord.
        metadata associated to the SIP calls

        :return: The to_domain of this HomerRecord.
        :rtype: str
        """
        return self._to_domain

    @to_domain.setter
    def to_domain(self, to_domain):
        """
        Sets the to_domain of this HomerRecord.
        metadata associated to the SIP calls

        :param to_domain: The to_domain of this HomerRecord.
        :type: str
        """
        
        self._to_domain = to_domain

    @property
    def to_tag(self):
        """
        Gets the to_tag of this HomerRecord.
        metadata associated to the SIP calls

        :return: The to_tag of this HomerRecord.
        :rtype: str
        """
        return self._to_tag

    @to_tag.setter
    def to_tag(self, to_tag):
        """
        Sets the to_tag of this HomerRecord.
        metadata associated to the SIP calls

        :param to_tag: The to_tag of this HomerRecord.
        :type: str
        """
        
        self._to_tag = to_tag

    @property
    def pid_user(self):
        """
        Gets the pid_user of this HomerRecord.
        metadata associated to the SIP calls

        :return: The pid_user of this HomerRecord.
        :rtype: str
        """
        return self._pid_user

    @pid_user.setter
    def pid_user(self, pid_user):
        """
        Sets the pid_user of this HomerRecord.
        metadata associated to the SIP calls

        :param pid_user: The pid_user of this HomerRecord.
        :type: str
        """
        
        self._pid_user = pid_user

    @property
    def contact_user(self):
        """
        Gets the contact_user of this HomerRecord.
        metadata associated to the SIP calls

        :return: The contact_user of this HomerRecord.
        :rtype: str
        """
        return self._contact_user

    @contact_user.setter
    def contact_user(self, contact_user):
        """
        Sets the contact_user of this HomerRecord.
        metadata associated to the SIP calls

        :param contact_user: The contact_user of this HomerRecord.
        :type: str
        """
        
        self._contact_user = contact_user

    @property
    def auth_user(self):
        """
        Gets the auth_user of this HomerRecord.
        metadata associated to the SIP calls

        :return: The auth_user of this HomerRecord.
        :rtype: str
        """
        return self._auth_user

    @auth_user.setter
    def auth_user(self, auth_user):
        """
        Sets the auth_user of this HomerRecord.
        metadata associated to the SIP calls

        :param auth_user: The auth_user of this HomerRecord.
        :type: str
        """
        
        self._auth_user = auth_user

    @property
    def callid(self):
        """
        Gets the callid of this HomerRecord.
        metadata associated to the SIP calls

        :return: The callid of this HomerRecord.
        :rtype: str
        """
        return self._callid

    @callid.setter
    def callid(self, callid):
        """
        Sets the callid of this HomerRecord.
        metadata associated to the SIP calls

        :param callid: The callid of this HomerRecord.
        :type: str
        """
        
        self._callid = callid

    @property
    def callid_aleg(self):
        """
        Gets the callid_aleg of this HomerRecord.
        metadata associated to the SIP calls

        :return: The callid_aleg of this HomerRecord.
        :rtype: str
        """
        return self._callid_aleg

    @callid_aleg.setter
    def callid_aleg(self, callid_aleg):
        """
        Sets the callid_aleg of this HomerRecord.
        metadata associated to the SIP calls

        :param callid_aleg: The callid_aleg of this HomerRecord.
        :type: str
        """
        
        self._callid_aleg = callid_aleg

    @property
    def via1(self):
        """
        Gets the via1 of this HomerRecord.
        metadata associated to the SIP calls

        :return: The via1 of this HomerRecord.
        :rtype: str
        """
        return self._via1

    @via1.setter
    def via1(self, via1):
        """
        Sets the via1 of this HomerRecord.
        metadata associated to the SIP calls

        :param via1: The via1 of this HomerRecord.
        :type: str
        """
        
        self._via1 = via1

    @property
    def via1_branch(self):
        """
        Gets the via1_branch of this HomerRecord.
        metadata associated to the SIP calls

        :return: The via1_branch of this HomerRecord.
        :rtype: str
        """
        return self._via1_branch

    @via1_branch.setter
    def via1_branch(self, via1_branch):
        """
        Sets the via1_branch of this HomerRecord.
        metadata associated to the SIP calls

        :param via1_branch: The via1_branch of this HomerRecord.
        :type: str
        """
        
        self._via1_branch = via1_branch

    @property
    def cseq(self):
        """
        Gets the cseq of this HomerRecord.
        metadata associated to the SIP calls

        :return: The cseq of this HomerRecord.
        :rtype: str
        """
        return self._cseq

    @cseq.setter
    def cseq(self, cseq):
        """
        Sets the cseq of this HomerRecord.
        metadata associated to the SIP calls

        :param cseq: The cseq of this HomerRecord.
        :type: str
        """
        
        self._cseq = cseq

    @property
    def diversion(self):
        """
        Gets the diversion of this HomerRecord.
        metadata associated to the SIP calls

        :return: The diversion of this HomerRecord.
        :rtype: str
        """
        return self._diversion

    @diversion.setter
    def diversion(self, diversion):
        """
        Sets the diversion of this HomerRecord.
        metadata associated to the SIP calls

        :param diversion: The diversion of this HomerRecord.
        :type: str
        """
        
        self._diversion = diversion

    @property
    def reason(self):
        """
        Gets the reason of this HomerRecord.
        metadata associated to the SIP calls

        :return: The reason of this HomerRecord.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this HomerRecord.
        metadata associated to the SIP calls

        :param reason: The reason of this HomerRecord.
        :type: str
        """
        
        self._reason = reason

    @property
    def content_type(self):
        """
        Gets the content_type of this HomerRecord.
        metadata associated to the SIP calls

        :return: The content_type of this HomerRecord.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this HomerRecord.
        metadata associated to the SIP calls

        :param content_type: The content_type of this HomerRecord.
        :type: str
        """
        
        self._content_type = content_type

    @property
    def auth(self):
        """
        Gets the auth of this HomerRecord.
        metadata associated to the SIP calls

        :return: The auth of this HomerRecord.
        :rtype: str
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """
        Sets the auth of this HomerRecord.
        metadata associated to the SIP calls

        :param auth: The auth of this HomerRecord.
        :type: str
        """
        
        self._auth = auth

    @property
    def user_agent(self):
        """
        Gets the user_agent of this HomerRecord.
        metadata associated to the SIP calls

        :return: The user_agent of this HomerRecord.
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """
        Sets the user_agent of this HomerRecord.
        metadata associated to the SIP calls

        :param user_agent: The user_agent of this HomerRecord.
        :type: str
        """
        
        self._user_agent = user_agent

    @property
    def source_ip(self):
        """
        Gets the source_ip of this HomerRecord.
        metadata associated to the SIP calls

        :return: The source_ip of this HomerRecord.
        :rtype: str
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, source_ip):
        """
        Sets the source_ip of this HomerRecord.
        metadata associated to the SIP calls

        :param source_ip: The source_ip of this HomerRecord.
        :type: str
        """
        
        self._source_ip = source_ip

    @property
    def source_port(self):
        """
        Gets the source_port of this HomerRecord.
        metadata associated to the SIP calls

        :return: The source_port of this HomerRecord.
        :rtype: str
        """
        return self._source_port

    @source_port.setter
    def source_port(self, source_port):
        """
        Sets the source_port of this HomerRecord.
        metadata associated to the SIP calls

        :param source_port: The source_port of this HomerRecord.
        :type: str
        """
        
        self._source_port = source_port

    @property
    def destination_ip(self):
        """
        Gets the destination_ip of this HomerRecord.
        metadata associated to the SIP calls

        :return: The destination_ip of this HomerRecord.
        :rtype: str
        """
        return self._destination_ip

    @destination_ip.setter
    def destination_ip(self, destination_ip):
        """
        Sets the destination_ip of this HomerRecord.
        metadata associated to the SIP calls

        :param destination_ip: The destination_ip of this HomerRecord.
        :type: str
        """
        
        self._destination_ip = destination_ip

    @property
    def destination_port(self):
        """
        Gets the destination_port of this HomerRecord.
        metadata associated to the SIP calls

        :return: The destination_port of this HomerRecord.
        :rtype: str
        """
        return self._destination_port

    @destination_port.setter
    def destination_port(self, destination_port):
        """
        Sets the destination_port of this HomerRecord.
        metadata associated to the SIP calls

        :param destination_port: The destination_port of this HomerRecord.
        :type: str
        """
        
        self._destination_port = destination_port

    @property
    def contact_ip(self):
        """
        Gets the contact_ip of this HomerRecord.
        metadata associated to the SIP calls

        :return: The contact_ip of this HomerRecord.
        :rtype: str
        """
        return self._contact_ip

    @contact_ip.setter
    def contact_ip(self, contact_ip):
        """
        Sets the contact_ip of this HomerRecord.
        metadata associated to the SIP calls

        :param contact_ip: The contact_ip of this HomerRecord.
        :type: str
        """
        
        self._contact_ip = contact_ip

    @property
    def contact_port(self):
        """
        Gets the contact_port of this HomerRecord.
        metadata associated to the SIP calls

        :return: The contact_port of this HomerRecord.
        :rtype: str
        """
        return self._contact_port

    @contact_port.setter
    def contact_port(self, contact_port):
        """
        Sets the contact_port of this HomerRecord.
        metadata associated to the SIP calls

        :param contact_port: The contact_port of this HomerRecord.
        :type: str
        """
        
        self._contact_port = contact_port

    @property
    def originator_ip(self):
        """
        Gets the originator_ip of this HomerRecord.
        metadata associated to the SIP calls

        :return: The originator_ip of this HomerRecord.
        :rtype: str
        """
        return self._originator_ip

    @originator_ip.setter
    def originator_ip(self, originator_ip):
        """
        Sets the originator_ip of this HomerRecord.
        metadata associated to the SIP calls

        :param originator_ip: The originator_ip of this HomerRecord.
        :type: str
        """
        
        self._originator_ip = originator_ip

    @property
    def originator_port(self):
        """
        Gets the originator_port of this HomerRecord.
        metadata associated to the SIP calls

        :return: The originator_port of this HomerRecord.
        :rtype: str
        """
        return self._originator_port

    @originator_port.setter
    def originator_port(self, originator_port):
        """
        Sets the originator_port of this HomerRecord.
        metadata associated to the SIP calls

        :param originator_port: The originator_port of this HomerRecord.
        :type: str
        """
        
        self._originator_port = originator_port

    @property
    def correlation_id(self):
        """
        Gets the correlation_id of this HomerRecord.
        metadata associated to the SIP calls

        :return: The correlation_id of this HomerRecord.
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """
        Sets the correlation_id of this HomerRecord.
        metadata associated to the SIP calls

        :param correlation_id: The correlation_id of this HomerRecord.
        :type: str
        """
        
        self._correlation_id = correlation_id

    @property
    def proto(self):
        """
        Gets the proto of this HomerRecord.
        metadata associated to the SIP calls

        :return: The proto of this HomerRecord.
        :rtype: str
        """
        return self._proto

    @proto.setter
    def proto(self, proto):
        """
        Sets the proto of this HomerRecord.
        metadata associated to the SIP calls

        :param proto: The proto of this HomerRecord.
        :type: str
        """
        
        self._proto = proto

    @property
    def family(self):
        """
        Gets the family of this HomerRecord.
        metadata associated to the SIP calls

        :return: The family of this HomerRecord.
        :rtype: str
        """
        return self._family

    @family.setter
    def family(self, family):
        """
        Sets the family of this HomerRecord.
        metadata associated to the SIP calls

        :param family: The family of this HomerRecord.
        :type: str
        """
        
        self._family = family

    @property
    def rtp_stat(self):
        """
        Gets the rtp_stat of this HomerRecord.
        metadata associated to the SIP calls

        :return: The rtp_stat of this HomerRecord.
        :rtype: str
        """
        return self._rtp_stat

    @rtp_stat.setter
    def rtp_stat(self, rtp_stat):
        """
        Sets the rtp_stat of this HomerRecord.
        metadata associated to the SIP calls

        :param rtp_stat: The rtp_stat of this HomerRecord.
        :type: str
        """
        
        self._rtp_stat = rtp_stat

    @property
    def type(self):
        """
        Gets the type of this HomerRecord.
        metadata associated to the SIP calls

        :return: The type of this HomerRecord.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this HomerRecord.
        metadata associated to the SIP calls

        :param type: The type of this HomerRecord.
        :type: str
        """
        
        self._type = type

    @property
    def node(self):
        """
        Gets the node of this HomerRecord.
        metadata associated to the SIP calls

        :return: The node of this HomerRecord.
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """
        Sets the node of this HomerRecord.
        metadata associated to the SIP calls

        :param node: The node of this HomerRecord.
        :type: str
        """
        
        self._node = node

    @property
    def trans(self):
        """
        Gets the trans of this HomerRecord.
        metadata associated to the SIP calls

        :return: The trans of this HomerRecord.
        :rtype: str
        """
        return self._trans

    @trans.setter
    def trans(self, trans):
        """
        Sets the trans of this HomerRecord.
        metadata associated to the SIP calls

        :param trans: The trans of this HomerRecord.
        :type: str
        """
        
        self._trans = trans

    @property
    def dbnode(self):
        """
        Gets the dbnode of this HomerRecord.
        metadata associated to the SIP calls

        :return: The dbnode of this HomerRecord.
        :rtype: str
        """
        return self._dbnode

    @dbnode.setter
    def dbnode(self, dbnode):
        """
        Sets the dbnode of this HomerRecord.
        metadata associated to the SIP calls

        :param dbnode: The dbnode of this HomerRecord.
        :type: str
        """
        
        self._dbnode = dbnode

    @property
    def msg(self):
        """
        Gets the msg of this HomerRecord.
        metadata associated to the SIP calls

        :return: The msg of this HomerRecord.
        :rtype: str
        """
        return self._msg

    @msg.setter
    def msg(self, msg):
        """
        Sets the msg of this HomerRecord.
        metadata associated to the SIP calls

        :param msg: The msg of this HomerRecord.
        :type: str
        """
        
        self._msg = msg

    @property
    def source_alias(self):
        """
        Gets the source_alias of this HomerRecord.
        metadata associated to the SIP calls

        :return: The source_alias of this HomerRecord.
        :rtype: str
        """
        return self._source_alias

    @source_alias.setter
    def source_alias(self, source_alias):
        """
        Sets the source_alias of this HomerRecord.
        metadata associated to the SIP calls

        :param source_alias: The source_alias of this HomerRecord.
        :type: str
        """
        
        self._source_alias = source_alias

    @property
    def destination_alias(self):
        """
        Gets the destination_alias of this HomerRecord.
        metadata associated to the SIP calls

        :return: The destination_alias of this HomerRecord.
        :rtype: str
        """
        return self._destination_alias

    @destination_alias.setter
    def destination_alias(self, destination_alias):
        """
        Sets the destination_alias of this HomerRecord.
        metadata associated to the SIP calls

        :param destination_alias: The destination_alias of this HomerRecord.
        :type: str
        """
        
        self._destination_alias = destination_alias

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this HomerRecord.
        metadata associated to the SIP calls

        :return: The conversation_id of this HomerRecord.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this HomerRecord.
        metadata associated to the SIP calls

        :param conversation_id: The conversation_id of this HomerRecord.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def participant_id(self):
        """
        Gets the participant_id of this HomerRecord.
        metadata associated to the SIP calls

        :return: The participant_id of this HomerRecord.
        :rtype: str
        """
        return self._participant_id

    @participant_id.setter
    def participant_id(self, participant_id):
        """
        Sets the participant_id of this HomerRecord.
        metadata associated to the SIP calls

        :param participant_id: The participant_id of this HomerRecord.
        :type: str
        """
        
        self._participant_id = participant_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this HomerRecord.
        The URI for this object

        :return: The self_uri of this HomerRecord.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this HomerRecord.
        The URI for this object

        :param self_uri: The self_uri of this HomerRecord.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SmsPhoneNumber(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SmsPhoneNumber - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'phone_number': 'str',
            'phone_number_type': 'str',
            'provisioned_through_pure_cloud': 'bool',
            'phone_number_status': 'str',
            'capabilities': 'list[str]',
            'country_code': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'created_by': 'User',
            'modified_by': 'User',
            'version': 'int',
            'purchase_date': 'datetime',
            'cancellation_date': 'datetime',
            'renewal_date': 'datetime',
            'auto_renewable': 'str',
            'address_id': 'SmsAddress',
            'short_code_billing_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'phone_number': 'phoneNumber',
            'phone_number_type': 'phoneNumberType',
            'provisioned_through_pure_cloud': 'provisionedThroughPureCloud',
            'phone_number_status': 'phoneNumberStatus',
            'capabilities': 'capabilities',
            'country_code': 'countryCode',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'created_by': 'createdBy',
            'modified_by': 'modifiedBy',
            'version': 'version',
            'purchase_date': 'purchaseDate',
            'cancellation_date': 'cancellationDate',
            'renewal_date': 'renewalDate',
            'auto_renewable': 'autoRenewable',
            'address_id': 'addressId',
            'short_code_billing_type': 'shortCodeBillingType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._phone_number = None
        self._phone_number_type = None
        self._provisioned_through_pure_cloud = None
        self._phone_number_status = None
        self._capabilities = None
        self._country_code = None
        self._date_created = None
        self._date_modified = None
        self._created_by = None
        self._modified_by = None
        self._version = None
        self._purchase_date = None
        self._cancellation_date = None
        self._renewal_date = None
        self._auto_renewable = None
        self._address_id = None
        self._short_code_billing_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SmsPhoneNumber.
        The globally unique identifier for the object.

        :return: The id of this SmsPhoneNumber.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SmsPhoneNumber.
        The globally unique identifier for the object.

        :param id: The id of this SmsPhoneNumber.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SmsPhoneNumber.


        :return: The name of this SmsPhoneNumber.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SmsPhoneNumber.


        :param name: The name of this SmsPhoneNumber.
        :type: str
        """
        
        self._name = name

    @property
    def phone_number(self):
        """
        Gets the phone_number of this SmsPhoneNumber.
        A phone number provisioned for SMS communications in E.164 format. E.g. +13175555555 or +34234234234

        :return: The phone_number of this SmsPhoneNumber.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this SmsPhoneNumber.
        A phone number provisioned for SMS communications in E.164 format. E.g. +13175555555 or +34234234234

        :param phone_number: The phone_number of this SmsPhoneNumber.
        :type: str
        """
        
        self._phone_number = phone_number

    @property
    def phone_number_type(self):
        """
        Gets the phone_number_type of this SmsPhoneNumber.
        Type of the phone number provisioned.

        :return: The phone_number_type of this SmsPhoneNumber.
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """
        Sets the phone_number_type of this SmsPhoneNumber.
        Type of the phone number provisioned.

        :param phone_number_type: The phone_number_type of this SmsPhoneNumber.
        :type: str
        """
        allowed_values = ["local", "mobile", "tollfree", "shortcode"]
        if phone_number_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for phone_number_type -> " + phone_number_type)
            self._phone_number_type = "outdated_sdk_version"
        else:
            self._phone_number_type = phone_number_type

    @property
    def provisioned_through_pure_cloud(self):
        """
        Gets the provisioned_through_pure_cloud of this SmsPhoneNumber.
        Is set to false, if the phone number is provisioned through a SMS provider, outside of PureCloud

        :return: The provisioned_through_pure_cloud of this SmsPhoneNumber.
        :rtype: bool
        """
        return self._provisioned_through_pure_cloud

    @provisioned_through_pure_cloud.setter
    def provisioned_through_pure_cloud(self, provisioned_through_pure_cloud):
        """
        Sets the provisioned_through_pure_cloud of this SmsPhoneNumber.
        Is set to false, if the phone number is provisioned through a SMS provider, outside of PureCloud

        :param provisioned_through_pure_cloud: The provisioned_through_pure_cloud of this SmsPhoneNumber.
        :type: bool
        """
        
        self._provisioned_through_pure_cloud = provisioned_through_pure_cloud

    @property
    def phone_number_status(self):
        """
        Gets the phone_number_status of this SmsPhoneNumber.
        Status of the provisioned phone number.

        :return: The phone_number_status of this SmsPhoneNumber.
        :rtype: str
        """
        return self._phone_number_status

    @phone_number_status.setter
    def phone_number_status(self, phone_number_status):
        """
        Sets the phone_number_status of this SmsPhoneNumber.
        Status of the provisioned phone number.

        :param phone_number_status: The phone_number_status of this SmsPhoneNumber.
        :type: str
        """
        allowed_values = ["INVALID", "ACTIVE", "PORTING", "PENDING", "PENDING_CANCELLATION"]
        if phone_number_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for phone_number_status -> " + phone_number_status)
            self._phone_number_status = "outdated_sdk_version"
        else:
            self._phone_number_status = phone_number_status

    @property
    def capabilities(self):
        """
        Gets the capabilities of this SmsPhoneNumber.
        The capabilities of the phone number available for provisioning.

        :return: The capabilities of this SmsPhoneNumber.
        :rtype: list[str]
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """
        Sets the capabilities of this SmsPhoneNumber.
        The capabilities of the phone number available for provisioning.

        :param capabilities: The capabilities of this SmsPhoneNumber.
        :type: list[str]
        """
        
        self._capabilities = capabilities

    @property
    def country_code(self):
        """
        Gets the country_code of this SmsPhoneNumber.
        The ISO 3166-1 alpha-2 country code of the country this phone number is associated with.

        :return: The country_code of this SmsPhoneNumber.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this SmsPhoneNumber.
        The ISO 3166-1 alpha-2 country code of the country this phone number is associated with.

        :param country_code: The country_code of this SmsPhoneNumber.
        :type: str
        """
        
        self._country_code = country_code

    @property
    def date_created(self):
        """
        Gets the date_created of this SmsPhoneNumber.
        Date this phone number was provisioned. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this SmsPhoneNumber.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this SmsPhoneNumber.
        Date this phone number was provisioned. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this SmsPhoneNumber.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this SmsPhoneNumber.
        Date this phone number was modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this SmsPhoneNumber.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this SmsPhoneNumber.
        Date this phone number was modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this SmsPhoneNumber.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def created_by(self):
        """
        Gets the created_by of this SmsPhoneNumber.
        User that provisioned this phone number

        :return: The created_by of this SmsPhoneNumber.
        :rtype: User
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this SmsPhoneNumber.
        User that provisioned this phone number

        :param created_by: The created_by of this SmsPhoneNumber.
        :type: User
        """
        
        self._created_by = created_by

    @property
    def modified_by(self):
        """
        Gets the modified_by of this SmsPhoneNumber.
        User that last modified this phone number

        :return: The modified_by of this SmsPhoneNumber.
        :rtype: User
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this SmsPhoneNumber.
        User that last modified this phone number

        :param modified_by: The modified_by of this SmsPhoneNumber.
        :type: User
        """
        
        self._modified_by = modified_by

    @property
    def version(self):
        """
        Gets the version of this SmsPhoneNumber.
        Version number required for updates.

        :return: The version of this SmsPhoneNumber.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SmsPhoneNumber.
        Version number required for updates.

        :param version: The version of this SmsPhoneNumber.
        :type: int
        """
        
        self._version = version

    @property
    def purchase_date(self):
        """
        Gets the purchase_date of this SmsPhoneNumber.
        Date this phone number was purchased, if the phoneNumberType is shortcode. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The purchase_date of this SmsPhoneNumber.
        :rtype: datetime
        """
        return self._purchase_date

    @purchase_date.setter
    def purchase_date(self, purchase_date):
        """
        Sets the purchase_date of this SmsPhoneNumber.
        Date this phone number was purchased, if the phoneNumberType is shortcode. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param purchase_date: The purchase_date of this SmsPhoneNumber.
        :type: datetime
        """
        
        self._purchase_date = purchase_date

    @property
    def cancellation_date(self):
        """
        Gets the cancellation_date of this SmsPhoneNumber.
        Contract end date of this phone number, if the phoneNumberType is shortcode. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The cancellation_date of this SmsPhoneNumber.
        :rtype: datetime
        """
        return self._cancellation_date

    @cancellation_date.setter
    def cancellation_date(self, cancellation_date):
        """
        Sets the cancellation_date of this SmsPhoneNumber.
        Contract end date of this phone number, if the phoneNumberType is shortcode. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param cancellation_date: The cancellation_date of this SmsPhoneNumber.
        :type: datetime
        """
        
        self._cancellation_date = cancellation_date

    @property
    def renewal_date(self):
        """
        Gets the renewal_date of this SmsPhoneNumber.
        Contract renewal date of this phone number, if the phoneNumberType is shortcode. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The renewal_date of this SmsPhoneNumber.
        :rtype: datetime
        """
        return self._renewal_date

    @renewal_date.setter
    def renewal_date(self, renewal_date):
        """
        Sets the renewal_date of this SmsPhoneNumber.
        Contract renewal date of this phone number, if the phoneNumberType is shortcode. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param renewal_date: The renewal_date of this SmsPhoneNumber.
        :type: datetime
        """
        
        self._renewal_date = renewal_date

    @property
    def auto_renewable(self):
        """
        Gets the auto_renewable of this SmsPhoneNumber.
        Renewal time period of this phone number, if the phoneNumberType is shortcode.

        :return: The auto_renewable of this SmsPhoneNumber.
        :rtype: str
        """
        return self._auto_renewable

    @auto_renewable.setter
    def auto_renewable(self, auto_renewable):
        """
        Sets the auto_renewable of this SmsPhoneNumber.
        Renewal time period of this phone number, if the phoneNumberType is shortcode.

        :param auto_renewable: The auto_renewable of this SmsPhoneNumber.
        :type: str
        """
        allowed_values = ["Quarterly"]
        if auto_renewable.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for auto_renewable -> " + auto_renewable)
            self._auto_renewable = "outdated_sdk_version"
        else:
            self._auto_renewable = auto_renewable

    @property
    def address_id(self):
        """
        Gets the address_id of this SmsPhoneNumber.
        The id of an address attached to this phone number.

        :return: The address_id of this SmsPhoneNumber.
        :rtype: SmsAddress
        """
        return self._address_id

    @address_id.setter
    def address_id(self, address_id):
        """
        Sets the address_id of this SmsPhoneNumber.
        The id of an address attached to this phone number.

        :param address_id: The address_id of this SmsPhoneNumber.
        :type: SmsAddress
        """
        
        self._address_id = address_id

    @property
    def short_code_billing_type(self):
        """
        Gets the short_code_billing_type of this SmsPhoneNumber.
        BillingType of this phone number, if the phoneNumberType is shortcode.

        :return: The short_code_billing_type of this SmsPhoneNumber.
        :rtype: str
        """
        return self._short_code_billing_type

    @short_code_billing_type.setter
    def short_code_billing_type(self, short_code_billing_type):
        """
        Sets the short_code_billing_type of this SmsPhoneNumber.
        BillingType of this phone number, if the phoneNumberType is shortcode.

        :param short_code_billing_type: The short_code_billing_type of this SmsPhoneNumber.
        :type: str
        """
        allowed_values = ["Basic", "Vanity"]
        if short_code_billing_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for short_code_billing_type -> " + short_code_billing_type)
            self._short_code_billing_type = "outdated_sdk_version"
        else:
            self._short_code_billing_type = short_code_billing_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SmsPhoneNumber.
        The URI for this object

        :return: The self_uri of this SmsPhoneNumber.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SmsPhoneNumber.
        The URI for this object

        :param self_uri: The self_uri of this SmsPhoneNumber.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ShiftTradeSettings(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ShiftTradeSettings - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'enabled': 'bool',
            'auto_review': 'bool',
            'allow_direct_trades': 'bool',
            'min_hours_in_future': 'int',
            'unequal_paid': 'str',
            'one_sided': 'str',
            'weekly_min_paid_violations': 'str',
            'weekly_max_paid_violations': 'str',
            'requires_matching_queues': 'bool',
            'requires_matching_languages': 'bool',
            'requires_matching_skills': 'bool',
            'requires_matching_planning_groups': 'bool',
            'activity_category_rules': 'list[ShiftTradeActivityRule]'
        }

        self.attribute_map = {
            'enabled': 'enabled',
            'auto_review': 'autoReview',
            'allow_direct_trades': 'allowDirectTrades',
            'min_hours_in_future': 'minHoursInFuture',
            'unequal_paid': 'unequalPaid',
            'one_sided': 'oneSided',
            'weekly_min_paid_violations': 'weeklyMinPaidViolations',
            'weekly_max_paid_violations': 'weeklyMaxPaidViolations',
            'requires_matching_queues': 'requiresMatchingQueues',
            'requires_matching_languages': 'requiresMatchingLanguages',
            'requires_matching_skills': 'requiresMatchingSkills',
            'requires_matching_planning_groups': 'requiresMatchingPlanningGroups',
            'activity_category_rules': 'activityCategoryRules'
        }

        self._enabled = None
        self._auto_review = None
        self._allow_direct_trades = None
        self._min_hours_in_future = None
        self._unequal_paid = None
        self._one_sided = None
        self._weekly_min_paid_violations = None
        self._weekly_max_paid_violations = None
        self._requires_matching_queues = None
        self._requires_matching_languages = None
        self._requires_matching_skills = None
        self._requires_matching_planning_groups = None
        self._activity_category_rules = None

    @property
    def enabled(self):
        """
        Gets the enabled of this ShiftTradeSettings.
        Whether shift trading is enabled for this management unit

        :return: The enabled of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ShiftTradeSettings.
        Whether shift trading is enabled for this management unit

        :param enabled: The enabled of this ShiftTradeSettings.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def auto_review(self):
        """
        Gets the auto_review of this ShiftTradeSettings.
        Whether automatic shift trade review is enabled according to the rules defined in for this management unit

        :return: The auto_review of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._auto_review

    @auto_review.setter
    def auto_review(self, auto_review):
        """
        Sets the auto_review of this ShiftTradeSettings.
        Whether automatic shift trade review is enabled according to the rules defined in for this management unit

        :param auto_review: The auto_review of this ShiftTradeSettings.
        :type: bool
        """
        
        self._auto_review = auto_review

    @property
    def allow_direct_trades(self):
        """
        Gets the allow_direct_trades of this ShiftTradeSettings.
        Whether direct shift trades between agents are allowed

        :return: The allow_direct_trades of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._allow_direct_trades

    @allow_direct_trades.setter
    def allow_direct_trades(self, allow_direct_trades):
        """
        Sets the allow_direct_trades of this ShiftTradeSettings.
        Whether direct shift trades between agents are allowed

        :param allow_direct_trades: The allow_direct_trades of this ShiftTradeSettings.
        :type: bool
        """
        
        self._allow_direct_trades = allow_direct_trades

    @property
    def min_hours_in_future(self):
        """
        Gets the min_hours_in_future of this ShiftTradeSettings.
        The minimum number of hours in the future shift trades are allowed

        :return: The min_hours_in_future of this ShiftTradeSettings.
        :rtype: int
        """
        return self._min_hours_in_future

    @min_hours_in_future.setter
    def min_hours_in_future(self, min_hours_in_future):
        """
        Sets the min_hours_in_future of this ShiftTradeSettings.
        The minimum number of hours in the future shift trades are allowed

        :param min_hours_in_future: The min_hours_in_future of this ShiftTradeSettings.
        :type: int
        """
        
        self._min_hours_in_future = min_hours_in_future

    @property
    def unequal_paid(self):
        """
        Gets the unequal_paid of this ShiftTradeSettings.
        How to handle shift trades which involve unequal paid times

        :return: The unequal_paid of this ShiftTradeSettings.
        :rtype: str
        """
        return self._unequal_paid

    @unequal_paid.setter
    def unequal_paid(self, unequal_paid):
        """
        Sets the unequal_paid of this ShiftTradeSettings.
        How to handle shift trades which involve unequal paid times

        :param unequal_paid: The unequal_paid of this ShiftTradeSettings.
        :type: str
        """
        allowed_values = ["Allow", "Disallow", "AdminReview"]
        if unequal_paid.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for unequal_paid -> " + unequal_paid)
            self._unequal_paid = "outdated_sdk_version"
        else:
            self._unequal_paid = unequal_paid

    @property
    def one_sided(self):
        """
        Gets the one_sided of this ShiftTradeSettings.
        How to handle one-sided shift trades

        :return: The one_sided of this ShiftTradeSettings.
        :rtype: str
        """
        return self._one_sided

    @one_sided.setter
    def one_sided(self, one_sided):
        """
        Sets the one_sided of this ShiftTradeSettings.
        How to handle one-sided shift trades

        :param one_sided: The one_sided of this ShiftTradeSettings.
        :type: str
        """
        allowed_values = ["Allow", "Disallow", "AdminReview"]
        if one_sided.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for one_sided -> " + one_sided)
            self._one_sided = "outdated_sdk_version"
        else:
            self._one_sided = one_sided

    @property
    def weekly_min_paid_violations(self):
        """
        Gets the weekly_min_paid_violations of this ShiftTradeSettings.
        How to handle shift trades which result in violations of weekly minimum paid time constraint

        :return: The weekly_min_paid_violations of this ShiftTradeSettings.
        :rtype: str
        """
        return self._weekly_min_paid_violations

    @weekly_min_paid_violations.setter
    def weekly_min_paid_violations(self, weekly_min_paid_violations):
        """
        Sets the weekly_min_paid_violations of this ShiftTradeSettings.
        How to handle shift trades which result in violations of weekly minimum paid time constraint

        :param weekly_min_paid_violations: The weekly_min_paid_violations of this ShiftTradeSettings.
        :type: str
        """
        allowed_values = ["Allow", "Disallow", "AdminReview"]
        if weekly_min_paid_violations.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for weekly_min_paid_violations -> " + weekly_min_paid_violations)
            self._weekly_min_paid_violations = "outdated_sdk_version"
        else:
            self._weekly_min_paid_violations = weekly_min_paid_violations

    @property
    def weekly_max_paid_violations(self):
        """
        Gets the weekly_max_paid_violations of this ShiftTradeSettings.
        How to handle shift trades which result in violations of weekly maximum paid time constraint

        :return: The weekly_max_paid_violations of this ShiftTradeSettings.
        :rtype: str
        """
        return self._weekly_max_paid_violations

    @weekly_max_paid_violations.setter
    def weekly_max_paid_violations(self, weekly_max_paid_violations):
        """
        Sets the weekly_max_paid_violations of this ShiftTradeSettings.
        How to handle shift trades which result in violations of weekly maximum paid time constraint

        :param weekly_max_paid_violations: The weekly_max_paid_violations of this ShiftTradeSettings.
        :type: str
        """
        allowed_values = ["Allow", "Disallow", "AdminReview"]
        if weekly_max_paid_violations.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for weekly_max_paid_violations -> " + weekly_max_paid_violations)
            self._weekly_max_paid_violations = "outdated_sdk_version"
        else:
            self._weekly_max_paid_violations = weekly_max_paid_violations

    @property
    def requires_matching_queues(self):
        """
        Gets the requires_matching_queues of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching queues

        :return: The requires_matching_queues of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._requires_matching_queues

    @requires_matching_queues.setter
    def requires_matching_queues(self, requires_matching_queues):
        """
        Sets the requires_matching_queues of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching queues

        :param requires_matching_queues: The requires_matching_queues of this ShiftTradeSettings.
        :type: bool
        """
        
        self._requires_matching_queues = requires_matching_queues

    @property
    def requires_matching_languages(self):
        """
        Gets the requires_matching_languages of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching languages

        :return: The requires_matching_languages of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._requires_matching_languages

    @requires_matching_languages.setter
    def requires_matching_languages(self, requires_matching_languages):
        """
        Sets the requires_matching_languages of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching languages

        :param requires_matching_languages: The requires_matching_languages of this ShiftTradeSettings.
        :type: bool
        """
        
        self._requires_matching_languages = requires_matching_languages

    @property
    def requires_matching_skills(self):
        """
        Gets the requires_matching_skills of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching skills

        :return: The requires_matching_skills of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._requires_matching_skills

    @requires_matching_skills.setter
    def requires_matching_skills(self, requires_matching_skills):
        """
        Sets the requires_matching_skills of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching skills

        :param requires_matching_skills: The requires_matching_skills of this ShiftTradeSettings.
        :type: bool
        """
        
        self._requires_matching_skills = requires_matching_skills

    @property
    def requires_matching_planning_groups(self):
        """
        Gets the requires_matching_planning_groups of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching planning groups

        :return: The requires_matching_planning_groups of this ShiftTradeSettings.
        :rtype: bool
        """
        return self._requires_matching_planning_groups

    @requires_matching_planning_groups.setter
    def requires_matching_planning_groups(self, requires_matching_planning_groups):
        """
        Sets the requires_matching_planning_groups of this ShiftTradeSettings.
        Whether to constrain shift trades to agents with matching planning groups

        :param requires_matching_planning_groups: The requires_matching_planning_groups of this ShiftTradeSettings.
        :type: bool
        """
        
        self._requires_matching_planning_groups = requires_matching_planning_groups

    @property
    def activity_category_rules(self):
        """
        Gets the activity_category_rules of this ShiftTradeSettings.
        Rules that specify what to do with activity categories that are part of a shift defined in a trade

        :return: The activity_category_rules of this ShiftTradeSettings.
        :rtype: list[ShiftTradeActivityRule]
        """
        return self._activity_category_rules

    @activity_category_rules.setter
    def activity_category_rules(self, activity_category_rules):
        """
        Sets the activity_category_rules of this ShiftTradeSettings.
        Rules that specify what to do with activity categories that are part of a shift defined in a trade

        :param activity_category_rules: The activity_category_rules of this ShiftTradeSettings.
        :type: list[ShiftTradeActivityRule]
        """
        
        self._activity_category_rules = activity_category_rules

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EvaluationQualityV2TopicEvaluationV2(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EvaluationQualityV2TopicEvaluationV2 - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'conversation_id': 'str',
            'agent': 'EvaluationQualityV2TopicUser',
            'evaluator': 'EvaluationQualityV2TopicUser',
            'event_time': 'datetime',
            'evaluation_form_id': 'str',
            'form_name': 'str',
            'scoring_set': 'EvaluationQualityV2TopicEvaluationScoringSet',
            'context_id': 'str',
            'status': 'str',
            'agent_has_read': 'bool',
            'release_date': 'datetime',
            'assigned_date': 'datetime',
            'changed_date': 'datetime',
            'event_type': 'str',
            'resource_id': 'str',
            'resource_type': 'str',
            'division_ids': 'list[str]',
            'rescore': 'bool',
            'conversation_date': 'datetime',
            'media_type': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'conversation_id': 'conversationId',
            'agent': 'agent',
            'evaluator': 'evaluator',
            'event_time': 'eventTime',
            'evaluation_form_id': 'evaluationFormId',
            'form_name': 'formName',
            'scoring_set': 'scoringSet',
            'context_id': 'contextId',
            'status': 'status',
            'agent_has_read': 'agentHasRead',
            'release_date': 'releaseDate',
            'assigned_date': 'assignedDate',
            'changed_date': 'changedDate',
            'event_type': 'eventType',
            'resource_id': 'resourceId',
            'resource_type': 'resourceType',
            'division_ids': 'divisionIds',
            'rescore': 'rescore',
            'conversation_date': 'conversationDate',
            'media_type': 'mediaType'
        }

        self._id = None
        self._conversation_id = None
        self._agent = None
        self._evaluator = None
        self._event_time = None
        self._evaluation_form_id = None
        self._form_name = None
        self._scoring_set = None
        self._context_id = None
        self._status = None
        self._agent_has_read = None
        self._release_date = None
        self._assigned_date = None
        self._changed_date = None
        self._event_type = None
        self._resource_id = None
        self._resource_type = None
        self._division_ids = None
        self._rescore = None
        self._conversation_date = None
        self._media_type = None

    @property
    def id(self):
        """
        Gets the id of this EvaluationQualityV2TopicEvaluationV2.


        :return: The id of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EvaluationQualityV2TopicEvaluationV2.


        :param id: The id of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._id = id

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this EvaluationQualityV2TopicEvaluationV2.


        :return: The conversation_id of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this EvaluationQualityV2TopicEvaluationV2.


        :param conversation_id: The conversation_id of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def agent(self):
        """
        Gets the agent of this EvaluationQualityV2TopicEvaluationV2.


        :return: The agent of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: EvaluationQualityV2TopicUser
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """
        Sets the agent of this EvaluationQualityV2TopicEvaluationV2.


        :param agent: The agent of this EvaluationQualityV2TopicEvaluationV2.
        :type: EvaluationQualityV2TopicUser
        """
        
        self._agent = agent

    @property
    def evaluator(self):
        """
        Gets the evaluator of this EvaluationQualityV2TopicEvaluationV2.


        :return: The evaluator of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: EvaluationQualityV2TopicUser
        """
        return self._evaluator

    @evaluator.setter
    def evaluator(self, evaluator):
        """
        Sets the evaluator of this EvaluationQualityV2TopicEvaluationV2.


        :param evaluator: The evaluator of this EvaluationQualityV2TopicEvaluationV2.
        :type: EvaluationQualityV2TopicUser
        """
        
        self._evaluator = evaluator

    @property
    def event_time(self):
        """
        Gets the event_time of this EvaluationQualityV2TopicEvaluationV2.


        :return: The event_time of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """
        Sets the event_time of this EvaluationQualityV2TopicEvaluationV2.


        :param event_time: The event_time of this EvaluationQualityV2TopicEvaluationV2.
        :type: datetime
        """
        
        self._event_time = event_time

    @property
    def evaluation_form_id(self):
        """
        Gets the evaluation_form_id of this EvaluationQualityV2TopicEvaluationV2.


        :return: The evaluation_form_id of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._evaluation_form_id

    @evaluation_form_id.setter
    def evaluation_form_id(self, evaluation_form_id):
        """
        Sets the evaluation_form_id of this EvaluationQualityV2TopicEvaluationV2.


        :param evaluation_form_id: The evaluation_form_id of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._evaluation_form_id = evaluation_form_id

    @property
    def form_name(self):
        """
        Gets the form_name of this EvaluationQualityV2TopicEvaluationV2.


        :return: The form_name of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._form_name

    @form_name.setter
    def form_name(self, form_name):
        """
        Sets the form_name of this EvaluationQualityV2TopicEvaluationV2.


        :param form_name: The form_name of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._form_name = form_name

    @property
    def scoring_set(self):
        """
        Gets the scoring_set of this EvaluationQualityV2TopicEvaluationV2.


        :return: The scoring_set of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: EvaluationQualityV2TopicEvaluationScoringSet
        """
        return self._scoring_set

    @scoring_set.setter
    def scoring_set(self, scoring_set):
        """
        Sets the scoring_set of this EvaluationQualityV2TopicEvaluationV2.


        :param scoring_set: The scoring_set of this EvaluationQualityV2TopicEvaluationV2.
        :type: EvaluationQualityV2TopicEvaluationScoringSet
        """
        
        self._scoring_set = scoring_set

    @property
    def context_id(self):
        """
        Gets the context_id of this EvaluationQualityV2TopicEvaluationV2.


        :return: The context_id of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """
        Sets the context_id of this EvaluationQualityV2TopicEvaluationV2.


        :param context_id: The context_id of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._context_id = context_id

    @property
    def status(self):
        """
        Gets the status of this EvaluationQualityV2TopicEvaluationV2.


        :return: The status of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this EvaluationQualityV2TopicEvaluationV2.


        :param status: The status of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        allowed_values = ["Pending", "InProgress", "Finished"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def agent_has_read(self):
        """
        Gets the agent_has_read of this EvaluationQualityV2TopicEvaluationV2.


        :return: The agent_has_read of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: bool
        """
        return self._agent_has_read

    @agent_has_read.setter
    def agent_has_read(self, agent_has_read):
        """
        Sets the agent_has_read of this EvaluationQualityV2TopicEvaluationV2.


        :param agent_has_read: The agent_has_read of this EvaluationQualityV2TopicEvaluationV2.
        :type: bool
        """
        
        self._agent_has_read = agent_has_read

    @property
    def release_date(self):
        """
        Gets the release_date of this EvaluationQualityV2TopicEvaluationV2.


        :return: The release_date of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: datetime
        """
        return self._release_date

    @release_date.setter
    def release_date(self, release_date):
        """
        Sets the release_date of this EvaluationQualityV2TopicEvaluationV2.


        :param release_date: The release_date of this EvaluationQualityV2TopicEvaluationV2.
        :type: datetime
        """
        
        self._release_date = release_date

    @property
    def assigned_date(self):
        """
        Gets the assigned_date of this EvaluationQualityV2TopicEvaluationV2.


        :return: The assigned_date of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: datetime
        """
        return self._assigned_date

    @assigned_date.setter
    def assigned_date(self, assigned_date):
        """
        Sets the assigned_date of this EvaluationQualityV2TopicEvaluationV2.


        :param assigned_date: The assigned_date of this EvaluationQualityV2TopicEvaluationV2.
        :type: datetime
        """
        
        self._assigned_date = assigned_date

    @property
    def changed_date(self):
        """
        Gets the changed_date of this EvaluationQualityV2TopicEvaluationV2.


        :return: The changed_date of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: datetime
        """
        return self._changed_date

    @changed_date.setter
    def changed_date(self, changed_date):
        """
        Sets the changed_date of this EvaluationQualityV2TopicEvaluationV2.


        :param changed_date: The changed_date of this EvaluationQualityV2TopicEvaluationV2.
        :type: datetime
        """
        
        self._changed_date = changed_date

    @property
    def event_type(self):
        """
        Gets the event_type of this EvaluationQualityV2TopicEvaluationV2.


        :return: The event_type of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """
        Sets the event_type of this EvaluationQualityV2TopicEvaluationV2.


        :param event_type: The event_type of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._event_type = event_type

    @property
    def resource_id(self):
        """
        Gets the resource_id of this EvaluationQualityV2TopicEvaluationV2.


        :return: The resource_id of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this EvaluationQualityV2TopicEvaluationV2.


        :param resource_id: The resource_id of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """
        Gets the resource_type of this EvaluationQualityV2TopicEvaluationV2.


        :return: The resource_type of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this EvaluationQualityV2TopicEvaluationV2.


        :param resource_type: The resource_type of this EvaluationQualityV2TopicEvaluationV2.
        :type: str
        """
        
        self._resource_type = resource_type

    @property
    def division_ids(self):
        """
        Gets the division_ids of this EvaluationQualityV2TopicEvaluationV2.


        :return: The division_ids of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: list[str]
        """
        return self._division_ids

    @division_ids.setter
    def division_ids(self, division_ids):
        """
        Sets the division_ids of this EvaluationQualityV2TopicEvaluationV2.


        :param division_ids: The division_ids of this EvaluationQualityV2TopicEvaluationV2.
        :type: list[str]
        """
        
        self._division_ids = division_ids

    @property
    def rescore(self):
        """
        Gets the rescore of this EvaluationQualityV2TopicEvaluationV2.


        :return: The rescore of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: bool
        """
        return self._rescore

    @rescore.setter
    def rescore(self, rescore):
        """
        Sets the rescore of this EvaluationQualityV2TopicEvaluationV2.


        :param rescore: The rescore of this EvaluationQualityV2TopicEvaluationV2.
        :type: bool
        """
        
        self._rescore = rescore

    @property
    def conversation_date(self):
        """
        Gets the conversation_date of this EvaluationQualityV2TopicEvaluationV2.


        :return: The conversation_date of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: datetime
        """
        return self._conversation_date

    @conversation_date.setter
    def conversation_date(self, conversation_date):
        """
        Sets the conversation_date of this EvaluationQualityV2TopicEvaluationV2.


        :param conversation_date: The conversation_date of this EvaluationQualityV2TopicEvaluationV2.
        :type: datetime
        """
        
        self._conversation_date = conversation_date

    @property
    def media_type(self):
        """
        Gets the media_type of this EvaluationQualityV2TopicEvaluationV2.


        :return: The media_type of this EvaluationQualityV2TopicEvaluationV2.
        :rtype: list[str]
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this EvaluationQualityV2TopicEvaluationV2.


        :param media_type: The media_type of this EvaluationQualityV2TopicEvaluationV2.
        :type: list[str]
        """
        
        self._media_type = media_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerRulesetConfigChangeDataActionConditionPredicate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerRulesetConfigChangeDataActionConditionPredicate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'output_field': 'str',
            'output_operator': 'str',
            'comparison_value': 'str',
            'output_field_missing_resolution': 'bool',
            'inverted': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'output_field': 'outputField',
            'output_operator': 'outputOperator',
            'comparison_value': 'comparisonValue',
            'output_field_missing_resolution': 'outputFieldMissingResolution',
            'inverted': 'inverted',
            'additional_properties': 'additionalProperties'
        }

        self._output_field = None
        self._output_operator = None
        self._comparison_value = None
        self._output_field_missing_resolution = None
        self._inverted = None
        self._additional_properties = None

    @property
    def output_field(self):
        """
        Gets the output_field of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :return: The output_field of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :rtype: str
        """
        return self._output_field

    @output_field.setter
    def output_field(self, output_field):
        """
        Sets the output_field of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :param output_field: The output_field of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :type: str
        """
        
        self._output_field = output_field

    @property
    def output_operator(self):
        """
        Gets the output_operator of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :return: The output_operator of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :rtype: str
        """
        return self._output_operator

    @output_operator.setter
    def output_operator(self, output_operator):
        """
        Sets the output_operator of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :param output_operator: The output_operator of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :type: str
        """
        allowed_values = ["EQUALS", "LESS_THAN", "LESS_THAN_EQUALS", "GREATER_THAN", "GREATER_THAN_EQUALS", "CONTAINS", "BEGINS_WITH", "ENDS_WITH", "BEFORE", "AFTER"]
        if output_operator.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for output_operator -> " + output_operator)
            self._output_operator = "outdated_sdk_version"
        else:
            self._output_operator = output_operator

    @property
    def comparison_value(self):
        """
        Gets the comparison_value of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :return: The comparison_value of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :rtype: str
        """
        return self._comparison_value

    @comparison_value.setter
    def comparison_value(self, comparison_value):
        """
        Sets the comparison_value of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :param comparison_value: The comparison_value of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :type: str
        """
        
        self._comparison_value = comparison_value

    @property
    def output_field_missing_resolution(self):
        """
        Gets the output_field_missing_resolution of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :return: The output_field_missing_resolution of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :rtype: bool
        """
        return self._output_field_missing_resolution

    @output_field_missing_resolution.setter
    def output_field_missing_resolution(self, output_field_missing_resolution):
        """
        Sets the output_field_missing_resolution of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :param output_field_missing_resolution: The output_field_missing_resolution of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :type: bool
        """
        
        self._output_field_missing_resolution = output_field_missing_resolution

    @property
    def inverted(self):
        """
        Gets the inverted of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :return: The inverted of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :rtype: bool
        """
        return self._inverted

    @inverted.setter
    def inverted(self, inverted):
        """
        Sets the inverted of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :param inverted: The inverted of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :type: bool
        """
        
        self._inverted = inverted

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :return: The additional_properties of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerRulesetConfigChangeDataActionConditionPredicate.


        :param additional_properties: The additional_properties of this DialerRulesetConfigChangeDataActionConditionPredicate.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContentActions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContentActions - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'url': 'str',
            'url_target': 'str',
            'textback': 'str',
            'command_name': 'str',
            'context': 'dict(str, object)'
        }

        self.attribute_map = {
            'url': 'url',
            'url_target': 'urlTarget',
            'textback': 'textback',
            'command_name': 'commandName',
            'context': 'context'
        }

        self._url = None
        self._url_target = None
        self._textback = None
        self._command_name = None
        self._context = None

    @property
    def url(self):
        """
        Gets the url of this ContentActions.
        A URL for a web page to redirect the user to

        :return: The url of this ContentActions.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this ContentActions.
        A URL for a web page to redirect the user to

        :param url: The url of this ContentActions.
        :type: str
        """
        
        self._url = url

    @property
    def url_target(self):
        """
        Gets the url_target of this ContentActions.
        The target window or tab within the URL's web page. If empty will open a blank page or tab.

        :return: The url_target of this ContentActions.
        :rtype: str
        """
        return self._url_target

    @url_target.setter
    def url_target(self, url_target):
        """
        Sets the url_target of this ContentActions.
        The target window or tab within the URL's web page. If empty will open a blank page or tab.

        :param url_target: The url_target of this ContentActions.
        :type: str
        """
        
        self._url_target = url_target

    @property
    def textback(self):
        """
        Gets the textback of this ContentActions.
        Text to be sent back in reply when a list item is selected

        :return: The textback of this ContentActions.
        :rtype: str
        """
        return self._textback

    @textback.setter
    def textback(self, textback):
        """
        Sets the textback of this ContentActions.
        Text to be sent back in reply when a list item is selected

        :param textback: The textback of this ContentActions.
        :type: str
        """
        
        self._textback = textback

    @property
    def command_name(self):
        """
        Gets the command_name of this ContentActions.
        Execute an organization's specific command

        :return: The command_name of this ContentActions.
        :rtype: str
        """
        return self._command_name

    @command_name.setter
    def command_name(self, command_name):
        """
        Sets the command_name of this ContentActions.
        Execute an organization's specific command

        :param command_name: The command_name of this ContentActions.
        :type: str
        """
        
        self._command_name = command_name

    @property
    def context(self):
        """
        Gets the context of this ContentActions.
        Additional context for the command

        :return: The context of this ContentActions.
        :rtype: dict(str, object)
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this ContentActions.
        Additional context for the command

        :param context: The context of this ContentActions.
        :type: dict(str, object)
        """
        
        self._context = context

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DocumentationResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DocumentationResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'categories': 'list[int]',
            'description': 'str',
            'content': 'str',
            'excerpt': 'str',
            'link': 'str',
            'modified': 'datetime',
            'name': 'str',
            'service': 'list[int]',
            'slug': 'str',
            'title': 'str',
            'get_type': 'str',
            'facet_feature': 'list[int]',
            'facet_role': 'list[int]',
            'facet_service': 'list[int]',
            'faq_categories': 'list[int]',
            'releasenote_category': 'list[int]',
            'releasenote_tag': 'list[int]',
            'service_area': 'list[int]',
            'video_categories': 'list[int]'
        }

        self.attribute_map = {
            'id': 'id',
            'categories': 'categories',
            'description': 'description',
            'content': 'content',
            'excerpt': 'excerpt',
            'link': 'link',
            'modified': 'modified',
            'name': 'name',
            'service': 'service',
            'slug': 'slug',
            'title': 'title',
            'get_type': 'get_type',
            'facet_feature': 'facet_feature',
            'facet_role': 'facet_role',
            'facet_service': 'facet_service',
            'faq_categories': 'faq_categories',
            'releasenote_category': 'releasenote_category',
            'releasenote_tag': 'releasenote_tag',
            'service_area': 'service-area',
            'video_categories': 'video_categories'
        }

        self._id = None
        self._categories = None
        self._description = None
        self._content = None
        self._excerpt = None
        self._link = None
        self._modified = None
        self._name = None
        self._service = None
        self._slug = None
        self._title = None
        self._get_type = None
        self._facet_feature = None
        self._facet_role = None
        self._facet_service = None
        self._faq_categories = None
        self._releasenote_category = None
        self._releasenote_tag = None
        self._service_area = None
        self._video_categories = None

    @property
    def id(self):
        """
        Gets the id of this DocumentationResult.
        The globally unique identifier for the object.

        :return: The id of this DocumentationResult.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DocumentationResult.
        The globally unique identifier for the object.

        :param id: The id of this DocumentationResult.
        :type: int
        """
        
        self._id = id

    @property
    def categories(self):
        """
        Gets the categories of this DocumentationResult.
        The category of the documentation entity. Will be returned in responses for certain entities.

        :return: The categories of this DocumentationResult.
        :rtype: list[int]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this DocumentationResult.
        The category of the documentation entity. Will be returned in responses for certain entities.

        :param categories: The categories of this DocumentationResult.
        :type: list[int]
        """
        
        self._categories = categories

    @property
    def description(self):
        """
        Gets the description of this DocumentationResult.
        The description of the documentation entity. Will be returned in responses for certain entities.

        :return: The description of this DocumentationResult.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DocumentationResult.
        The description of the documentation entity. Will be returned in responses for certain entities.

        :param description: The description of this DocumentationResult.
        :type: str
        """
        
        self._description = description

    @property
    def content(self):
        """
        Gets the content of this DocumentationResult.
        The text or html content for the documentation entity. Will be returned in responses for certain entities.

        :return: The content of this DocumentationResult.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this DocumentationResult.
        The text or html content for the documentation entity. Will be returned in responses for certain entities.

        :param content: The content of this DocumentationResult.
        :type: str
        """
        
        self._content = content

    @property
    def excerpt(self):
        """
        Gets the excerpt of this DocumentationResult.
        The excerpt of the documentation entity. Will be returned in responses for certain entities.

        :return: The excerpt of this DocumentationResult.
        :rtype: str
        """
        return self._excerpt

    @excerpt.setter
    def excerpt(self, excerpt):
        """
        Sets the excerpt of this DocumentationResult.
        The excerpt of the documentation entity. Will be returned in responses for certain entities.

        :param excerpt: The excerpt of this DocumentationResult.
        :type: str
        """
        
        self._excerpt = excerpt

    @property
    def link(self):
        """
        Gets the link of this DocumentationResult.
        URL link for the documentation entity. Will be returned in responses for certain entities.

        :return: The link of this DocumentationResult.
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """
        Sets the link of this DocumentationResult.
        URL link for the documentation entity. Will be returned in responses for certain entities.

        :param link: The link of this DocumentationResult.
        :type: str
        """
        
        self._link = link

    @property
    def modified(self):
        """
        Gets the modified of this DocumentationResult.
        The modified date for the documentation entity. Will be returned in responses for certain entities. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified of this DocumentationResult.
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """
        Sets the modified of this DocumentationResult.
        The modified date for the documentation entity. Will be returned in responses for certain entities. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified: The modified of this DocumentationResult.
        :type: datetime
        """
        
        self._modified = modified

    @property
    def name(self):
        """
        Gets the name of this DocumentationResult.
        The name of the documentation entity. Will be returned in responses for certain entities.

        :return: The name of this DocumentationResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DocumentationResult.
        The name of the documentation entity. Will be returned in responses for certain entities.

        :param name: The name of this DocumentationResult.
        :type: str
        """
        
        self._name = name

    @property
    def service(self):
        """
        Gets the service of this DocumentationResult.
        The service of the documentation entity. Will be returned in responses for certain entities.

        :return: The service of this DocumentationResult.
        :rtype: list[int]
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this DocumentationResult.
        The service of the documentation entity. Will be returned in responses for certain entities.

        :param service: The service of this DocumentationResult.
        :type: list[int]
        """
        
        self._service = service

    @property
    def slug(self):
        """
        Gets the slug of this DocumentationResult.
        The slug of the documentation entity. Will be returned in responses for certain entities.

        :return: The slug of this DocumentationResult.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this DocumentationResult.
        The slug of the documentation entity. Will be returned in responses for certain entities.

        :param slug: The slug of this DocumentationResult.
        :type: str
        """
        
        self._slug = slug

    @property
    def title(self):
        """
        Gets the title of this DocumentationResult.
        The title of the documentation entity. Will be returned in responses for certain entities.

        :return: The title of this DocumentationResult.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this DocumentationResult.
        The title of the documentation entity. Will be returned in responses for certain entities.

        :param title: The title of this DocumentationResult.
        :type: str
        """
        
        self._title = title

    @property
    def get_type(self):
        """
        Gets the get_type of this DocumentationResult.
        The search type. Will be returned in responses for certain entities.

        :return: The get_type of this DocumentationResult.
        :rtype: str
        """
        return self._get_type

    @get_type.setter
    def get_type(self, get_type):
        """
        Sets the get_type of this DocumentationResult.
        The search type. Will be returned in responses for certain entities.

        :param get_type: The get_type of this DocumentationResult.
        :type: str
        """
        
        self._get_type = get_type

    @property
    def facet_feature(self):
        """
        Gets the facet_feature of this DocumentationResult.
        The facet feature of the documentation entity. Will be returned in responses for certain entities.

        :return: The facet_feature of this DocumentationResult.
        :rtype: list[int]
        """
        return self._facet_feature

    @facet_feature.setter
    def facet_feature(self, facet_feature):
        """
        Sets the facet_feature of this DocumentationResult.
        The facet feature of the documentation entity. Will be returned in responses for certain entities.

        :param facet_feature: The facet_feature of this DocumentationResult.
        :type: list[int]
        """
        
        self._facet_feature = facet_feature

    @property
    def facet_role(self):
        """
        Gets the facet_role of this DocumentationResult.
        The facet role of the documentation entity. Will be returned in responses for certain entities.

        :return: The facet_role of this DocumentationResult.
        :rtype: list[int]
        """
        return self._facet_role

    @facet_role.setter
    def facet_role(self, facet_role):
        """
        Sets the facet_role of this DocumentationResult.
        The facet role of the documentation entity. Will be returned in responses for certain entities.

        :param facet_role: The facet_role of this DocumentationResult.
        :type: list[int]
        """
        
        self._facet_role = facet_role

    @property
    def facet_service(self):
        """
        Gets the facet_service of this DocumentationResult.
        The facet service of the documentation entity. Will be returned in responses for certain entities.

        :return: The facet_service of this DocumentationResult.
        :rtype: list[int]
        """
        return self._facet_service

    @facet_service.setter
    def facet_service(self, facet_service):
        """
        Sets the facet_service of this DocumentationResult.
        The facet service of the documentation entity. Will be returned in responses for certain entities.

        :param facet_service: The facet_service of this DocumentationResult.
        :type: list[int]
        """
        
        self._facet_service = facet_service

    @property
    def faq_categories(self):
        """
        Gets the faq_categories of this DocumentationResult.
        The faq categories of the documentation entity. Will be returned in responses for certain entities.

        :return: The faq_categories of this DocumentationResult.
        :rtype: list[int]
        """
        return self._faq_categories

    @faq_categories.setter
    def faq_categories(self, faq_categories):
        """
        Sets the faq_categories of this DocumentationResult.
        The faq categories of the documentation entity. Will be returned in responses for certain entities.

        :param faq_categories: The faq_categories of this DocumentationResult.
        :type: list[int]
        """
        
        self._faq_categories = faq_categories

    @property
    def releasenote_category(self):
        """
        Gets the releasenote_category of this DocumentationResult.
        The releasenote category of the documentation entity. Will be returned in responses for certain entities.

        :return: The releasenote_category of this DocumentationResult.
        :rtype: list[int]
        """
        return self._releasenote_category

    @releasenote_category.setter
    def releasenote_category(self, releasenote_category):
        """
        Sets the releasenote_category of this DocumentationResult.
        The releasenote category of the documentation entity. Will be returned in responses for certain entities.

        :param releasenote_category: The releasenote_category of this DocumentationResult.
        :type: list[int]
        """
        
        self._releasenote_category = releasenote_category

    @property
    def releasenote_tag(self):
        """
        Gets the releasenote_tag of this DocumentationResult.
        The releasenote tag of the documentation entity. Will be returned in responses for certain entities.

        :return: The releasenote_tag of this DocumentationResult.
        :rtype: list[int]
        """
        return self._releasenote_tag

    @releasenote_tag.setter
    def releasenote_tag(self, releasenote_tag):
        """
        Sets the releasenote_tag of this DocumentationResult.
        The releasenote tag of the documentation entity. Will be returned in responses for certain entities.

        :param releasenote_tag: The releasenote_tag of this DocumentationResult.
        :type: list[int]
        """
        
        self._releasenote_tag = releasenote_tag

    @property
    def service_area(self):
        """
        Gets the service_area of this DocumentationResult.
        The service area of the documentation entity. Will be returned in responses for certain entities.

        :return: The service_area of this DocumentationResult.
        :rtype: list[int]
        """
        return self._service_area

    @service_area.setter
    def service_area(self, service_area):
        """
        Sets the service_area of this DocumentationResult.
        The service area of the documentation entity. Will be returned in responses for certain entities.

        :param service_area: The service_area of this DocumentationResult.
        :type: list[int]
        """
        
        self._service_area = service_area

    @property
    def video_categories(self):
        """
        Gets the video_categories of this DocumentationResult.
        The video categories of the documentation entity. Will be returned in responses for certain entities.

        :return: The video_categories of this DocumentationResult.
        :rtype: list[int]
        """
        return self._video_categories

    @video_categories.setter
    def video_categories(self, video_categories):
        """
        Sets the video_categories of this DocumentationResult.
        The video categories of the documentation entity. Will be returned in responses for certain entities.

        :param video_categories: The video_categories of this DocumentationResult.
        :type: list[int]
        """
        
        self._video_categories = video_categories

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SchedulingSettingsRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SchedulingSettingsRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'max_occupancy_percent_for_deferred_work': 'int',
            'default_shrinkage_percent': 'float',
            'shrinkage_overrides': 'ShrinkageOverrides',
            'planning_period': 'ValueWrapperPlanningPeriodSettings',
            'start_day_of_weekend': 'str'
        }

        self.attribute_map = {
            'max_occupancy_percent_for_deferred_work': 'maxOccupancyPercentForDeferredWork',
            'default_shrinkage_percent': 'defaultShrinkagePercent',
            'shrinkage_overrides': 'shrinkageOverrides',
            'planning_period': 'planningPeriod',
            'start_day_of_weekend': 'startDayOfWeekend'
        }

        self._max_occupancy_percent_for_deferred_work = None
        self._default_shrinkage_percent = None
        self._shrinkage_overrides = None
        self._planning_period = None
        self._start_day_of_weekend = None

    @property
    def max_occupancy_percent_for_deferred_work(self):
        """
        Gets the max_occupancy_percent_for_deferred_work of this SchedulingSettingsRequest.
        Max occupancy percent for deferred work

        :return: The max_occupancy_percent_for_deferred_work of this SchedulingSettingsRequest.
        :rtype: int
        """
        return self._max_occupancy_percent_for_deferred_work

    @max_occupancy_percent_for_deferred_work.setter
    def max_occupancy_percent_for_deferred_work(self, max_occupancy_percent_for_deferred_work):
        """
        Sets the max_occupancy_percent_for_deferred_work of this SchedulingSettingsRequest.
        Max occupancy percent for deferred work

        :param max_occupancy_percent_for_deferred_work: The max_occupancy_percent_for_deferred_work of this SchedulingSettingsRequest.
        :type: int
        """
        
        self._max_occupancy_percent_for_deferred_work = max_occupancy_percent_for_deferred_work

    @property
    def default_shrinkage_percent(self):
        """
        Gets the default_shrinkage_percent of this SchedulingSettingsRequest.
        Default shrinkage percent for scheduling

        :return: The default_shrinkage_percent of this SchedulingSettingsRequest.
        :rtype: float
        """
        return self._default_shrinkage_percent

    @default_shrinkage_percent.setter
    def default_shrinkage_percent(self, default_shrinkage_percent):
        """
        Sets the default_shrinkage_percent of this SchedulingSettingsRequest.
        Default shrinkage percent for scheduling

        :param default_shrinkage_percent: The default_shrinkage_percent of this SchedulingSettingsRequest.
        :type: float
        """
        
        self._default_shrinkage_percent = default_shrinkage_percent

    @property
    def shrinkage_overrides(self):
        """
        Gets the shrinkage_overrides of this SchedulingSettingsRequest.
        Shrinkage overrides for scheduling

        :return: The shrinkage_overrides of this SchedulingSettingsRequest.
        :rtype: ShrinkageOverrides
        """
        return self._shrinkage_overrides

    @shrinkage_overrides.setter
    def shrinkage_overrides(self, shrinkage_overrides):
        """
        Sets the shrinkage_overrides of this SchedulingSettingsRequest.
        Shrinkage overrides for scheduling

        :param shrinkage_overrides: The shrinkage_overrides of this SchedulingSettingsRequest.
        :type: ShrinkageOverrides
        """
        
        self._shrinkage_overrides = shrinkage_overrides

    @property
    def planning_period(self):
        """
        Gets the planning_period of this SchedulingSettingsRequest.
        Planning period settings for scheduling

        :return: The planning_period of this SchedulingSettingsRequest.
        :rtype: ValueWrapperPlanningPeriodSettings
        """
        return self._planning_period

    @planning_period.setter
    def planning_period(self, planning_period):
        """
        Sets the planning_period of this SchedulingSettingsRequest.
        Planning period settings for scheduling

        :param planning_period: The planning_period of this SchedulingSettingsRequest.
        :type: ValueWrapperPlanningPeriodSettings
        """
        
        self._planning_period = planning_period

    @property
    def start_day_of_weekend(self):
        """
        Gets the start_day_of_weekend of this SchedulingSettingsRequest.
        Start day of weekend for scheduling

        :return: The start_day_of_weekend of this SchedulingSettingsRequest.
        :rtype: str
        """
        return self._start_day_of_weekend

    @start_day_of_weekend.setter
    def start_day_of_weekend(self, start_day_of_weekend):
        """
        Sets the start_day_of_weekend of this SchedulingSettingsRequest.
        Start day of weekend for scheduling

        :param start_day_of_weekend: The start_day_of_weekend of this SchedulingSettingsRequest.
        :type: str
        """
        allowed_values = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"]
        if start_day_of_weekend.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for start_day_of_weekend -> " + start_day_of_weekend)
            self._start_day_of_weekend = "outdated_sdk_version"
        else:
            self._start_day_of_weekend = start_day_of_weekend

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ArrayNode(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ArrayNode - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'node_type': 'str',
            'float': 'bool',
            'number': 'bool',
            'boolean': 'bool',
            'object': 'bool',
            'value_node': 'bool',
            'container_node': 'bool',
            'floating_point_number': 'bool',
            'pojo': 'bool',
            'integral_number': 'bool',
            'short': 'bool',
            'int': 'bool',
            'long': 'bool',
            'double': 'bool',
            'big_decimal': 'bool',
            'big_integer': 'bool',
            'textual': 'bool',
            'binary': 'bool',
            'missing_node': 'bool',
            'array': 'bool',
            'null': 'bool'
        }

        self.attribute_map = {
            'node_type': 'nodeType',
            'float': 'float',
            'number': 'number',
            'boolean': 'boolean',
            'object': 'object',
            'value_node': 'valueNode',
            'container_node': 'containerNode',
            'floating_point_number': 'floatingPointNumber',
            'pojo': 'pojo',
            'integral_number': 'integralNumber',
            'short': 'short',
            'int': 'int',
            'long': 'long',
            'double': 'double',
            'big_decimal': 'bigDecimal',
            'big_integer': 'bigInteger',
            'textual': 'textual',
            'binary': 'binary',
            'missing_node': 'missingNode',
            'array': 'array',
            'null': 'null'
        }

        self._node_type = None
        self._float = None
        self._number = None
        self._boolean = None
        self._object = None
        self._value_node = None
        self._container_node = None
        self._floating_point_number = None
        self._pojo = None
        self._integral_number = None
        self._short = None
        self._int = None
        self._long = None
        self._double = None
        self._big_decimal = None
        self._big_integer = None
        self._textual = None
        self._binary = None
        self._missing_node = None
        self._array = None
        self._null = None

    @property
    def node_type(self):
        """
        Gets the node_type of this ArrayNode.


        :return: The node_type of this ArrayNode.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this ArrayNode.


        :param node_type: The node_type of this ArrayNode.
        :type: str
        """
        allowed_values = ["ARRAY", "BINARY", "BOOLEAN", "MISSING", "NULL", "NUMBER", "OBJECT", "POJO", "STRING"]
        if node_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for node_type -> " + node_type)
            self._node_type = "outdated_sdk_version"
        else:
            self._node_type = node_type

    @property
    def float(self):
        """
        Gets the float of this ArrayNode.


        :return: The float of this ArrayNode.
        :rtype: bool
        """
        return self._float

    @float.setter
    def float(self, float):
        """
        Sets the float of this ArrayNode.


        :param float: The float of this ArrayNode.
        :type: bool
        """
        
        self._float = float

    @property
    def number(self):
        """
        Gets the number of this ArrayNode.


        :return: The number of this ArrayNode.
        :rtype: bool
        """
        return self._number

    @number.setter
    def number(self, number):
        """
        Sets the number of this ArrayNode.


        :param number: The number of this ArrayNode.
        :type: bool
        """
        
        self._number = number

    @property
    def boolean(self):
        """
        Gets the boolean of this ArrayNode.


        :return: The boolean of this ArrayNode.
        :rtype: bool
        """
        return self._boolean

    @boolean.setter
    def boolean(self, boolean):
        """
        Sets the boolean of this ArrayNode.


        :param boolean: The boolean of this ArrayNode.
        :type: bool
        """
        
        self._boolean = boolean

    @property
    def object(self):
        """
        Gets the object of this ArrayNode.


        :return: The object of this ArrayNode.
        :rtype: bool
        """
        return self._object

    @object.setter
    def object(self, object):
        """
        Sets the object of this ArrayNode.


        :param object: The object of this ArrayNode.
        :type: bool
        """
        
        self._object = object

    @property
    def value_node(self):
        """
        Gets the value_node of this ArrayNode.


        :return: The value_node of this ArrayNode.
        :rtype: bool
        """
        return self._value_node

    @value_node.setter
    def value_node(self, value_node):
        """
        Sets the value_node of this ArrayNode.


        :param value_node: The value_node of this ArrayNode.
        :type: bool
        """
        
        self._value_node = value_node

    @property
    def container_node(self):
        """
        Gets the container_node of this ArrayNode.


        :return: The container_node of this ArrayNode.
        :rtype: bool
        """
        return self._container_node

    @container_node.setter
    def container_node(self, container_node):
        """
        Sets the container_node of this ArrayNode.


        :param container_node: The container_node of this ArrayNode.
        :type: bool
        """
        
        self._container_node = container_node

    @property
    def floating_point_number(self):
        """
        Gets the floating_point_number of this ArrayNode.


        :return: The floating_point_number of this ArrayNode.
        :rtype: bool
        """
        return self._floating_point_number

    @floating_point_number.setter
    def floating_point_number(self, floating_point_number):
        """
        Sets the floating_point_number of this ArrayNode.


        :param floating_point_number: The floating_point_number of this ArrayNode.
        :type: bool
        """
        
        self._floating_point_number = floating_point_number

    @property
    def pojo(self):
        """
        Gets the pojo of this ArrayNode.


        :return: The pojo of this ArrayNode.
        :rtype: bool
        """
        return self._pojo

    @pojo.setter
    def pojo(self, pojo):
        """
        Sets the pojo of this ArrayNode.


        :param pojo: The pojo of this ArrayNode.
        :type: bool
        """
        
        self._pojo = pojo

    @property
    def integral_number(self):
        """
        Gets the integral_number of this ArrayNode.


        :return: The integral_number of this ArrayNode.
        :rtype: bool
        """
        return self._integral_number

    @integral_number.setter
    def integral_number(self, integral_number):
        """
        Sets the integral_number of this ArrayNode.


        :param integral_number: The integral_number of this ArrayNode.
        :type: bool
        """
        
        self._integral_number = integral_number

    @property
    def short(self):
        """
        Gets the short of this ArrayNode.


        :return: The short of this ArrayNode.
        :rtype: bool
        """
        return self._short

    @short.setter
    def short(self, short):
        """
        Sets the short of this ArrayNode.


        :param short: The short of this ArrayNode.
        :type: bool
        """
        
        self._short = short

    @property
    def int(self):
        """
        Gets the int of this ArrayNode.


        :return: The int of this ArrayNode.
        :rtype: bool
        """
        return self._int

    @int.setter
    def int(self, int):
        """
        Sets the int of this ArrayNode.


        :param int: The int of this ArrayNode.
        :type: bool
        """
        
        self._int = int

    @property
    def long(self):
        """
        Gets the long of this ArrayNode.


        :return: The long of this ArrayNode.
        :rtype: bool
        """
        return self._long

    @long.setter
    def long(self, long):
        """
        Sets the long of this ArrayNode.


        :param long: The long of this ArrayNode.
        :type: bool
        """
        
        self._long = long

    @property
    def double(self):
        """
        Gets the double of this ArrayNode.


        :return: The double of this ArrayNode.
        :rtype: bool
        """
        return self._double

    @double.setter
    def double(self, double):
        """
        Sets the double of this ArrayNode.


        :param double: The double of this ArrayNode.
        :type: bool
        """
        
        self._double = double

    @property
    def big_decimal(self):
        """
        Gets the big_decimal of this ArrayNode.


        :return: The big_decimal of this ArrayNode.
        :rtype: bool
        """
        return self._big_decimal

    @big_decimal.setter
    def big_decimal(self, big_decimal):
        """
        Sets the big_decimal of this ArrayNode.


        :param big_decimal: The big_decimal of this ArrayNode.
        :type: bool
        """
        
        self._big_decimal = big_decimal

    @property
    def big_integer(self):
        """
        Gets the big_integer of this ArrayNode.


        :return: The big_integer of this ArrayNode.
        :rtype: bool
        """
        return self._big_integer

    @big_integer.setter
    def big_integer(self, big_integer):
        """
        Sets the big_integer of this ArrayNode.


        :param big_integer: The big_integer of this ArrayNode.
        :type: bool
        """
        
        self._big_integer = big_integer

    @property
    def textual(self):
        """
        Gets the textual of this ArrayNode.


        :return: The textual of this ArrayNode.
        :rtype: bool
        """
        return self._textual

    @textual.setter
    def textual(self, textual):
        """
        Sets the textual of this ArrayNode.


        :param textual: The textual of this ArrayNode.
        :type: bool
        """
        
        self._textual = textual

    @property
    def binary(self):
        """
        Gets the binary of this ArrayNode.


        :return: The binary of this ArrayNode.
        :rtype: bool
        """
        return self._binary

    @binary.setter
    def binary(self, binary):
        """
        Sets the binary of this ArrayNode.


        :param binary: The binary of this ArrayNode.
        :type: bool
        """
        
        self._binary = binary

    @property
    def missing_node(self):
        """
        Gets the missing_node of this ArrayNode.


        :return: The missing_node of this ArrayNode.
        :rtype: bool
        """
        return self._missing_node

    @missing_node.setter
    def missing_node(self, missing_node):
        """
        Sets the missing_node of this ArrayNode.


        :param missing_node: The missing_node of this ArrayNode.
        :type: bool
        """
        
        self._missing_node = missing_node

    @property
    def array(self):
        """
        Gets the array of this ArrayNode.


        :return: The array of this ArrayNode.
        :rtype: bool
        """
        return self._array

    @array.setter
    def array(self, array):
        """
        Sets the array of this ArrayNode.


        :param array: The array of this ArrayNode.
        :type: bool
        """
        
        self._array = array

    @property
    def null(self):
        """
        Gets the null of this ArrayNode.


        :return: The null of this ArrayNode.
        :rtype: bool
        """
        return self._null

    @null.setter
    def null(self, null):
        """
        Sets the null of this ArrayNode.


        :param null: The null of this ArrayNode.
        :type: bool
        """
        
        self._null = null

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

